%-----------loser.m---------------
%-----------Solving the equations--------
%----------Ole Kristian Nordvg---------
%----------22.05.2012-------------------

function dbdV = loser(V,b)

global Vend

MMass
constant
Reactorinlet
enthalpiesandCp

T0=298.15;
w=b(1:13);
T=b(14);
ptot=b(15);
Mmix=1/(sum(w./MMi'));
W=sum(w)
yi=w.*Mmix./MMi';
Y=sum(yi);
massin2=Min.*3600;    %mass in [kg/h]

pri=yi.*ptot;         %partial pressure of each component

Adsorb=pri(1)*(1+Kln22*pri(9)+Kliso22*pri(13)+Kln1522*pri(8)+Kliso1522*pri(12)...
    +Kln1014*pri(7)+Kliso1014*pri(11)+Kln59*pri(6)+Kliso59*pri(10)+Kln14*pri(5));

%reaction rates [kmol/(kgcat*h)]
if (pri(1)>0)
    r1=k0iso22*exp(-Eiso22/R/T)*(pri(9)-(pri(13)/Keq22))/Adsorb;
    r2=k0iso1522*exp(-Eiso1522/R/T)*(pri(8)-(pri(12)/Keq1522))/Adsorb;
    r3=k0iso1014*exp(-Eiso1014/R/T)*(pri(7)-(pri(11)/Keq1014))/Adsorb;
    r4=k0iso59*exp(-Eiso59/R/T)*(pri(6)-(pri(10)/Keq59))/Adsorb;
    r5=k0cr22*exp(-Ecr22/R/T)*pri(13)/Adsorb;
    r6=k0cr1522*exp(-Ecr1522/R/T)*(pri(12))/Adsorb;
    r7=k0cr1014*exp(-Ecr1014/R/T)*pri(11)/Adsorb;
    r8=k0cr59*exp(-Ecr59/R/T)*pri(10)/Adsorb;
else                                        %if/else is only used to make the simulation
    r1=0;                                   %converge when all hydrogen is consumed
    r2=0;
    r3=0;
    r4=0;
    r5=0;
    r6=0;
    r7=0;
    r8=0;
end

%MASS BALANCES
%----------------------------------------------
rn22=-r1;
riso22=r1+(1-my5-my5star)*r5-(my5+my5star)*r5;           
rn1522=-r2;
riso1522=r2+2*my5*r5-my6*r6-(1-my6)*r6;
rn1014=-r3;
riso1014=r3+2*(1-my6)*r6+2*my5star*r5-r7;           
rn59=-r4;
riso59=r4+2*r7+2*my6*r6-r8;
rn14=2*r8;
rH2=-(my5+my5star)*r5-r6-r7-r8;

% %dwi/dV [1/m3]
dwdVn1=MMi(5)*rhocat/massin2*rn14;              %nC1-4
dwdVn2=MMi(6)*rhocat/massin2*rn59;              %nC5-9
dwdVn3=MMi(7)*rhocat/massin2*rn1014;            %nC10-14
dwdVn4=MMi(8)*rhocat/massin2*rn1522;            %nC15-20
dwdVn5=MMi(9)*rhocat/massin2*rn22;              %nC21+
dwdVi1=MMi(10)*rhocat/massin2*riso59;           %iC5-9
dwdVi2=MMi(11)*rhocat/massin2*riso1014;         %iC10-14
dwdVi3=MMi(12)*rhocat/massin2*riso1522;         %iC15-20
dwdVi4=MMi(13)*rhocat/massin2*riso22;           %iC21+
dwdVH2=-(dwdVn1+dwdVn2+dwdVn3+dwdVn4+dwdVn5+dwdVi1+dwdVi2+dwdVi3+dwdVi4);
dwdVCO=0;
dwdVCO2=0;
dwdVH2O=0;

%ENERGY BALANCE
%----------------------------------------------------
Cpm=sum(Cp*w);                                   
DHf=DH0+Cp*(T-T0);

%Isomerisation reactions
DHrx1=(DHf(13)-DHf(9))*r1;
DHrx2=(DHf(12)-DHf(8))*r2;
DHrx3=(DHf(11)-DHf(7))*r3;
DHrx4=(DHf(10)-DHf(6))*r4;

%Cracking reactions
DHrx5=(2*my5*DHf(12)-my5*DHf(13)-DHf(1))*r5;
DHrx6=(2*(1-my6)*DHf(11)-(1-my6)*DHf(12)-DHf(1))*r6;
DHrx7=(2*DHf(10)-DHf(11)-DHf(1))*r7;
DHrx8=(2*DHf(5)-DHf(10)-DHf(1))*r8;
DHrx9=(2*my5star*DHf(11)-my5star*DHf(13)-DHf(1))*r5;
DHrx10=(2*my6*DHf(10)-my6*DHf(12)-DHf(1))*r6;

DHrx=[DHrx1 DHrx2 DHrx3 DHrx4 DHrx5 DHrx6 DHrx7 DHrx8 DHrx9 DHrx10];

dTdV=rhocat*Mmix/massin2/Cpm*-(sum(DHrx));


%%Pressure equation (Ergun's equation)
%----------------------------------------------------------------
rhogas=ptot*Mmix/R/T/1000;                                  %gas density [kg/m3]
vs=Vin/A                                                   %Superficial gas velocity [m/s]
Re=vs*dp*rhogas/mygas                                      %Reynolds number []
fric=(1-epsilon)/(epsilon^3)*(1.75+(150*(1-epsilon)/Re));   %friction factor

dpdV=-fric*rhogas*vs*vs/dp/A;                              %Pressure loss [Pa/m3]


dbdV=[dwdVH2 dwdVCO dwdVCO2 dwdVH2O dwdVn1 dwdVn2 dwdVn3 dwdVn4 ...
    dwdVn5 dwdVi1 dwdVi2 dwdVi3 dwdVi4 dTdV dpdV]';

