%-----------main.m----------------------
%----------odesolver and plotting-------
%---------Ole Kristian Nordvg----------
%-------------22.05.2012----------------

global Vend

constant        %Calling other files
MMass
Reactorinlet

step=1;
Vspan=[0:step:Vend];
b0=[win(1:4) sum(win(5:8)) sum(win(9:13)) sum(win(14:18)) sum(win(19:24)) win(25) win(26) win(27) win(28) win(29) Tin pin]';    %boundary conditions
nc=length(b0);

[V,b]=ode45(@loser,Vspan,b0)

for i=1:(Vend/step+1)
    MMix(i)=1/(sum(b(i,1:13)./MMi));
    y(i,:)=b(i,1:13).*MMix(i)./MMi;
    wnc(i,:)=b(i,5:9);
    wic(i,:)=b(i,10:13);
    ync(i,:)=y(i,5:9);  
    yic(i,:)=y(i,10:13);
end

%Plotting
%------------------------------------
figure(1)
plot(V,b(:,5:13))
legend('C1-4','C5-9','C10-14','C15-20','C21+','iC5-9','iC10-14','iC15-20','iC21+');
set(legend,'Location','North')
title('mass fractions of hydrocarbons')
xlabel('Volume [m3]')
ylabel('mass fractions')

figure(2)
plot(V,b(:,1:13))
legend('H2','CO','CO2','H2O','C1-4','C5-9','C10-14','C15-20','C21+','iC5-9','iC10-14','iC15-20','iC21+');
set(legend,'Location','Northeast')
title('mass fractions of all components')
xlabel('Volume [m3]')
ylabel('mass fractions')

figure(3)
plot(V,b(:,14)-273.15)
legend('T');
set(legend,'Location','North')
title('Temperature plot')
xlabel('Volume [m3]')
ylabel('Temperature [C]')

figure(4)
plot(V,b(:,15)/100000)
legend('ptot');
set(legend,'Location','North')
title('Pressure plot')
xlabel('Volume [m3]')
ylabel('Total pressure [bar]')
      
LPG=b(end,5)
naphta=b(end,6)+b(end,10)
kerosene=b(end,7)+b(end,11)
diesel=b(end,8)+b(end,12)
fueloil=b(end,9)+b(end,13)

wout=[0 0 b(end,5) 0 0 0 0 0 b(end,6) 0  0  0  0  b(end,7) 0  0  0  0  0  b(end,8) 0  0 b(end,9) 0 b(end,4) b(end,1) 0 b(end,2) b(end,3) b(end,10) sum(b(end,11)+b(end,12)+b(end,13))]

pause

%Sending values back to HYSYS
%----------------------------
g.Item('C1-4').TemperatureValue=b(end,14)-273.15;          
g.Item('C1-4').PressureValue=b(end,15)/1000;               
g.Item('C1-4').MassflowValue=Min*wout(3);
g.Item('C5-9').TemperatureValue=b(end,14)-273.15;          
g.Item('C5-9').PressureValue=b(end,15)/1000; 
g.Item('C5-9').MassflowValue=Min*wout(9);
g.Item('C10-14').TemperatureValue=b(end,14)-273.15;          
g.Item('C10-14').PressureValue=b(end,15)/1000; 
g.Item('C10-14').MassflowValue=Min*wout(14);
g.Item('C15-20').TemperatureValue=b(end,14)-273.15;          
g.Item('C15-20').PressureValue=b(end,15)/1000; 
g.Item('C15-20').MassflowValue=Min*wout(20);
g.Item('C21+').TemperatureValue=b(end,14)-273.15;          
g.Item('C21+').PressureValue=b(end,15)/1000; 
g.Item('C21+').MassflowValue=Min*wout(23);
g.Item('iC5-9').TemperatureValue=b(end,14)-273.15;          
g.Item('iC5-9').PressureValue=b(end,15)/1000; 
g.Item('iC5-9').MassflowValue=Min*wout(30);
g.Item('iC10+').TemperatureValue=b(end,14)-273.15;          
g.Item('iC10+').PressureValue=b(end,15)/1000; 
g.Item('iC10+').MassflowValue=Min*wout(31);
g.Item('H2').TemperatureValue=b(end,14)-273.15;          
g.Item('H2').PressureValue=b(end,15)/1000; 
g.Item('H2').MassflowValue=Min*wout(26);
g.Item('H2O').TemperatureValue=b(end,14)-273.15;          
g.Item('H2O').PressureValue=b(end,15)/1000; 
g.Item('H2O').MassflowValue=Min*wout(25);
g.Item('CO').TemperatureValue=b(end,14)-273.15;          
g.Item('CO').PressureValue=b(end,15)/1000; 
g.Item('CO').MassflowValue=Min*wout(28);
g.Item('CO2').TemperatureValue=b(end,14)-273.15;          
g.Item('CO2').PressureValue=b(end,15)/1000; 
g.Item('CO2').MassflowValue=Min*wout(29);